#
# This file is part of Invenio.
# Copyright (C) 2016-2018 CERN.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""postgres specific json field in taxonomy term json data"""
import sqlalchemy as sa
import sqlalchemy.dialects.postgresql
from alembic import op

# revision identifiers, used by Alembic.
revision = '2f7c25afd313'
down_revision = 'e5848504dc5f'
branch_labels = ()
depends_on = None


def upgrade():
    """Upgrade database."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('taxonomy_term',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('slug', sa.String(length=64), nullable=True),
    sa.Column('extra_data', sa.JSON().with_variant(sqlalchemy.dialects.postgresql.JSON, 'postgresql'), nullable=True),
    sa.Column('tree_id', sa.Integer(), nullable=False),
    sa.Column('left', sa.Integer(), nullable=False),
    sa.Column('right', sa.Integer(), nullable=False),
    sa.Column('level', sa.Integer(), nullable=False),
    sa.Column('order', sa.Integer(), nullable=False),
    sa.Column('parent_id', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['parent_id'], ['taxonomy_term.id'], name=op.f('fk_taxonomy_term_parent_id_taxonomy_term')),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_taxonomy_term')),
    sa.UniqueConstraint('slug', 'parent_id', name='uq_taxonomy_term_slug_parent'),
    sa.UniqueConstraint('slug', 'tree_id', name='uq_taxonomy_term_slug_tree')
    )
    op.create_index(op.f('ix_taxonomy_term_slug'), 'taxonomy_term', ['slug'], unique=False)
    op.create_table('taxonomy_tree_id',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_taxonomy_tree_id'))
    )
    # ### end Alembic commands ###


def downgrade():
    """Downgrade database."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('taxonomy_tree_id')
    op.drop_index(op.f('ix_taxonomy_term_slug'), table_name='taxonomy_term')
    op.drop_table('taxonomy_term')
    # ### end Alembic commands ###
